# Congratulations!

You have completed all the projects in the Ready Set STEM CREATOR Kit, but that doesn't mean you have to stop creating!

All the components in your CREATOR Kit can be reused to conceive and build countless other projects, constrained only by your imagination. You can find fantastic tutorials and project ideas online or invent your own.

Here are a couple of places to start:

- Raspberry Pi Foundation (www.raspberrypi.org)

- Instructables (www.instructables.com)

If you want to learn more about Python or learn another programming language, you can check out these online courses:

- CodeCademy (www.codecademy.com)

- PythonRoom (www.pythonroom.com)

We would love to see what you invent with your CREATOR Kit! Please connect with us and keep us informed of your progress, and send us any great new projects you create -- with your permission, we may even add it to the kit and give you the credit you deserve:

- Twitter (twitter.com/readysetstem)

- Facebook (facebook.com/readysetstem)